This part of the project documentation
will focus on a **learning-oriented** approach.
You'll learn how to get started with the code in this project.

It is currently empty, but we will aim to:

- Help newcomers with getting started
- Teach readers about the library by having them write code
- Inspire confidence through examples that work for everyone, repeatably
- Give readers an immediate sense of achievement
- Show concrete examples without abstractions
- Provide the minimum necessary explanation
- Avoid any distraction
